@@ -71,6 +71,7 @@ command, for Go.
 		HTMLHighlightStyle        string `group:"html" help:"Style used for highlighting lines."`
 		HTMLBaseLine              int    `group:"html" help:"Base line number." default:"1"`
 		HTMLPreventSurroundingPre bool   `group:"html" help:"Prevent the surrounding pre tag."`
+		HTMLLinkableLines         bool   `group:"html" help:"Make the line numbers linkable and be a link to themselves."`
 
 		Files []string `arg:"" optional:"" help:"Files to highlight." type:"existingfile"`
 	}
@@ -204,21 +205,18 @@ func main() {
 	style, err := builder.Build()
 	ctx.FatalIfErrorf(err)
 
+	if cli.Formatter == "html" {
+		configureHTMLFormatter(ctx)
+	}
+
 	// Dump styles.
 	if cli.HTMLStyles {
-		options := []html.Option{html.WithClasses(true)}
-		if cli.HTMLAllStyles {
-			options = append(options, html.WithAllClasses(true))
-		}
-		formatter := html.New(options...)
+		formatter := formatters.Get("html").(*html.Formatter)
 		err = formatter.WriteCSS(w, style)
 		ctx.FatalIfErrorf(err)
 		return
 	}
 
-	if cli.Formatter == "html" {
-		configureHTMLFormatter(ctx)
-	}
 	if len(cli.Files) == 0 {
 		var contents string
 		var lexer chroma.Lexer
@@ -266,6 +264,7 @@ func configureHTMLFormatter(ctx *kong.Context) {
 		html.WithLineNumbers(cli.HTMLLines),
 		html.LineNumbersInTable(cli.HTMLLinesTable),
 		html.PreventSurroundingPre(cli.HTMLPreventSurroundingPre),
+		html.WithLinkableLineNumbers(cli.HTMLLinkableLines, "L"),
 	}
 	if len(cli.HTMLHighlight) > 0 {
 		ranges := [][2]int{}
