@@ -3,8 +3,8 @@ package formatters
 import (
 	"testing"
 
+	assert "github.com/alecthomas/assert/v2"
 	"github.com/alecthomas/chroma/v2"
-	"github.com/stretchr/testify/assert"
 )
 
 func TestClosestColour(t *testing.T) {
